@@ -41,14 +41,14 @@ def get_join(relation: RelationshipProperty):
                 join_table = l
                 join_table2 = r2
 
-        sf = sa.outerjoin(
+        sf = sa.join(
             base_table,
             join_table,
             relation.primaryjoin,
         )
 
         if join_table2 is not None:
-            sf = sf.outerjoin(
+            sf = sf.join(
                 join_table2,
                 relation.secondaryjoin,
             )
@@ -139,10 +139,9 @@ def generate_loader_by_relationship(relation: RelationshipProperty):
             results_by_ids = defaultdict(list)
 
             conversion_type = object_type or target
-            for result in await self.session.execute(q):
-                _data = dict(**result)
-                _batch_key = _data.pop("_batch_key")
-                _data = filter_requested_fields_for_object(_data, conversion_type)
+            for result in map(dict, await self.session.execute(q.distinct())):
+                _batch_key = result.pop("_batch_key")
+                _data = filter_requested_fields_for_object(result, conversion_type)
                 results_by_ids[_batch_key].append(conversion_type(**_data))
 
             return [results_by_ids.get(id, []) for id in keys]
@@ -167,14 +166,10 @@ def generate_loader_by_foreign_key(fk: ForeignKey, reverse=False):
         async def batch_load_fn(self, keys):
             if not reverse:
                 target_field = fk.column
-                source_field = fk.parent
                 target: Table = target_field.table
-                source: Table = source_field.table
             else:
                 target_field = fk.parent
-                source_field = fk.column
                 target: Table = target_field.table
-                source: Table = source_field.table
 
             object_types = getattr(self.info.context, "object_types", {})
             setattr(self.info.context, "keys", keys)
@@ -218,20 +213,9 @@ def generate_loader_by_foreign_key(fk: ForeignKey, reverse=False):
                 target_field.label("_batch_key"),
             ).where(target_field.in_(keys))
 
-            if target != source:
-                q = q.select_from(
-                    sa.outerjoin(
-                        target,
-                        source,
-                        target_field == source_field,
-                    )
-                )
-
             if object_type and hasattr(object_type, "set_select_from"):
                 setattr(self.info.context, "keys", keys)
                 q = await object_type.set_select_from(self.info, q, gql_field.values)
-                if list(q._group_by_clause):
-                    q = q.group_by(source_field)
 
             if filters:
                 q = q.where(sa.and_(*filters))
@@ -241,10 +225,9 @@ def generate_loader_by_foreign_key(fk: ForeignKey, reverse=False):
             results_by_ids = defaultdict(list)
 
             conversion_type = object_type or table_to_class(target)
-            results = list(map(dict, await self.session.execute(q.distinct())))
-            for _data in results:
-                _batch_key = _data.pop("_batch_key")
-                _data = filter_requested_fields_for_object(_data, conversion_type)
+            for result in map(dict, await self.session.execute(q.distinct())):
+                _batch_key = result.pop("_batch_key")
+                _data = filter_requested_fields_for_object(result, conversion_type)
                 results_by_ids[_batch_key].append(conversion_type(**_data))
 
             return [results_by_ids.get(id, []) for id in keys]
